<?php
/**
* This file represents an example of the code that themes would use to register
* the required plugins.
*
* It is expected that theme authors would copy and paste this code into their
* functions.php file, and amend to suit.
*
* @package    TGM-Plugin-Activation
* @subpackage Example
* @version    2.4.2
* @author     Thomas Griffin <thomasgriffinmedia.com>
    * @author     Gary Jones <gamajo.com>
        * @copyright  Copyright (c) 2014, Thomas Griffin
        * @license    http://opensource.org/licenses/gpl-2.0.php GPL v2 or later
        * @link       https://github.com/thomasgriffin/TGM-Plugin-Activation
        */

        /**
        * Include the TGM_Plugin_Activation class.
        */
        if ( ! class_exists( 'CMB2' ) ) {
        /**
        * Use plugin instead
        *
        * @deprecated 1.2.4
        */
        require_once get_template_directory(). '/inc/tgmpa/class-tgm-plugin-activation.php';
        }


        add_action( 'tgmpa_register', 'wpcoupon_theme_register_required_plugins' );
        /**
        * Register the required plugins for this theme.
        *
        * In this example, we register two plugins - one included with the TGMPA library
        * and one from the .org repo.
        *
        * The variable passed to tgmpa_register_plugins() should be an array of plugin
        * arrays.
        *
        * This function is hooked into tgmpa_init, which is fired within the
        * TGM_Plugin_Activation class constructor.
        */
        function wpcoupon_theme_register_required_plugins() {

        /**
        * Array of plugin arrays. Required keys are name and slug.
        * If the source is NOT from the .org repo, then source is also required.
        */
        $plugins = array(

            array(
                'name'      => esc_html__( 'Redux Framework', 'wp-coupon-pro' ),
                'slug'      => 'redux-framework',
                'source'    => '',
                'required'  => true,
                ),
        
                array(
                'name'      => esc_html__( 'Breadcrumb NavXT', 'wp-coupon-pro'  ),
                'slug'      => 'breadcrumb-navxt',
                'source'    => '',
                'required'  => false,
                ),
        
                array(
                'name'      => esc_html__( 'WP Users', 'wp-coupon-pro' ),
                'slug'      => 'wp-users',
                'source'    => get_template_directory() . '/recommend-plugins/wp-users.zip', // The plugin source.
                'required'  => true,
                'version'   => '1.0.0',
                ),
                array(
                'name'      =>'CMB2',
                'slug'      => 'cmb2',
                'source'    => '',
                'required'  => true,
                'force_activation'   => true, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch.
                ),
        
                array(
                'name'      => esc_html__( 'WPCoupon Demo Import', 'wp-coupon-pro'  ),
                'slug'      => 'wpcoupon-demo-import',
                'source'    => get_template_directory() . '/recommend-plugins/wpcoupon-demo-import.zip', // The plugin source.
                'required'  => false,
                'version'   => '1.0.0',
                ),
        
                array(
                'name'      => esc_html__( 'WPCoupon Frontend Submit Addon', 'wp-coupon-pro'  ),
                'slug'      => 'wpcoupon-frontend-submit-addon',
                'source'    => get_template_directory() . '/recommend-plugins/wpcoupon-frontend-submit-addon.zip', // The plugin source.
                'required'  => true,
                'version'   => '1.0.0',
                ),
                array(
                'name'      => esc_html__( 'BP Star Ratings', 'wp-coupon-pro' ),
                'slug'      => 'star-ratings',
                'source'    => get_template_directory() . '/recommend-plugins/BP-Star-Ratings.zip', // The plugin source.
                'required'  => false,
                'version'   => '1.8',
                ),
                array(
                'name'      => esc_html__( 'WP Menu Icons', 'wp-coupon-pro' ),
                'slug'      => 'wp-menu-icons',
                'source'    => '',
                'required'  => true,
                ),
                array(
                'name'      => esc_html__( 'Contact Form 7', 'wp-coupon-pro' ),
                'slug'      => 'contact-form-7',
                'source'    => '',
                'required'  => false,
                ),
        );

        /**
        * Array of configuration settings. Amend each line as needed.
        * If you want the default strings to be available under your own theme domain,
        * leave the strings uncommented.
        * Some of the strings are added into a sprintf, so see the comments at the
        * end of each line for what each argument will be.
        */
        $config = array(
        'default_path' => '',                      // Default absolute path to pre-packaged plugins.
        'menu'         => 'tgmpa-install-plugins', // Menu slug.
        'has_notices'  => true,                    // Show admin notices or not.
        'dismissable'  => true,                    // If false, a user cannot dismiss the nag message.
        'dismiss_msg'  => '',                      // If 'dismissable' is false, this message will be output at top of nag.
        'is_automatic' => false,                   // Automatically activate plugins after installation or not.
        'message'      => '',                      // Message to output right before the plugins table.
        'strings'      => array(
        'page_title'                      => esc_html__( 'Install Required Plugins', 'wp-coupon-pro' ),
        'menu_title'                      => esc_html__( 'Install Plugins', 'wp-coupon-pro' ),
        'installing'                      => esc_html__( 'Installing Plugin: %s', 'wp-coupon-pro' ), // %s = plugin name.
        'oops'                            => esc_html__( 'Something went wrong with the plugin API.', 'wp-coupon-pro' ),
        'notice_can_install_required'     => _n_noop( 'This theme requires the following plugin: %1$s.', 'This theme requires the following plugins: %1$s.', 'wp-coupon-pro' ), // %1$s = plugin name(s).
        'notice_can_install_recommended'  => _n_noop( 'This theme recommends the following plugin: %1$s.', 'This theme recommends the following plugins: %1$s.', 'wp-coupon-pro' ), // %1$s = plugin name(s).
        'notice_cannot_install'           => _n_noop( 'Sorry, but you do not have the correct permissions to install the %s plugin. Contact the administrator of this site for help on getting the plugin installed.', 'Sorry, but you do not have the correct permissions to install the %s plugins. Contact the administrator of this site for help on getting the plugins installed.', 'wp-coupon-pro' ), // %1$s = plugin name(s).
        'notice_can_activate_required'    => _n_noop( 'The following required plugin is currently inactive: %1$s.', 'The following required plugins are currently inactive: %1$s.' , 'wp-coupon-pro' ), // %1$s = plugin name(s).
        'notice_can_activate_recommended' => _n_noop( 'The following recommended plugin is currently inactive: %1$s.', 'The following recommended plugins are currently inactive: %1$s.', 'wp-coupon-pro' ), // %1$s = plugin name(s).
        'notice_cannot_activate'          => _n_noop( 'Sorry, but you do not have the correct permissions to activate the %s plugin. Contact the administrator of this site for help on getting the plugin activated.', 'Sorry, but you do not have the correct permissions to activate the %s plugins. Contact the administrator of this site for help on getting the plugins activated.', 'wp-coupon-pro' ), // %1$s = plugin name(s).
        'notice_ask_to_update'            => _n_noop( 'The following plugin needs to be updated to its latest version to ensure maximum compatibility with this theme: %1$s.', 'The following plugins need to be updated to their latest version to ensure maximum compatibility with this theme: %1$s.', 'wp-coupon-pro' ), // %1$s = plugin name(s).
        'notice_cannot_update'            => _n_noop( 'Sorry, but you do not have the correct permissions to update the %s plugin. Contact the administrator of this site for help on getting the plugin updated.', 'Sorry, but you do not have the correct permissions to update the %s plugins. Contact the administrator of this site for help on getting the plugins updated.', 'wp-coupon-pro' ), // %1$s = plugin name(s).
        'install_link'                    => _n_noop( 'Begin installing plugin', 'Begin installing plugins', 'wp-coupon-pro' ),
        'activate_link'                   => _n_noop( 'Begin activating plugin', 'Begin activating plugins', 'wp-coupon-pro' ),
        'return'                          => esc_html__( 'Return to Required Plugins Installer', 'wp-coupon-pro' ),
        'plugin_activated'                => esc_html__( 'Plugin activated successfully.', 'wp-coupon-pro' ),
        'complete'                        => esc_html__( 'All plugins installed and activated successfully. %s', 'wp-coupon-pro' ), // %s = dashboard link.
        'nag_type'                        => 'updated' // Determines admin notice type - can only be 'updated', 'update-nag' or 'error'.
        )
        );

        tgmpa( $plugins, $config );

        }